@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -42,7 +42,8 @@ using namespace Akregator;
 AkrWebEngineViewer::AkrWebEngineViewer(KActionCollection *ac, QWidget *parent)
     : ArticleViewerWebEngine(ac, parent)
 {
-    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, true);
+    //TODO update settings when we change config
+    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, Settings::enableJavascript());
     settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AutoLoadImages, true);
     settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, false);
@@ -91,11 +92,19 @@ void AkrWebEngineViewer::slotWebHitFinished(const WebEngineViewer::WebHitTestRes
     popup.addAction(pageAction(QWebEnginePage::Reload));
     popup.addSeparator();
 
-    const bool contentSelected = !selectedText().isEmpty();
-    if (!contentSelected) {
+    const bool noContentSelected = selectedText().isEmpty();
+    if (noContentSelected) {
         if (!mCurrentUrl.isEmpty()) {
-            popup.addAction(createOpenLinkInNewTabAction(mCurrentUrl, this, SLOT(slotOpenLinkInForegroundTab()), &popup));
-            popup.addAction(createOpenLinkInExternalBrowserAction(mCurrentUrl, this, SLOT(slotOpenLinkInBrowser()), &popup));
+            {
+                QAction *act = createOpenLinkInNewTabAction(mCurrentUrl, &popup);
+                connect(act, &QAction::triggered, this, &AkrWebEngineViewer::slotOpenLinkInBackgroundTab);
+                popup.addAction(act);
+            }
+            {
+                QAction *act = createOpenLinkInExternalBrowserAction(mCurrentUrl, &popup);
+                connect(act, &QAction::triggered, this, &AkrWebEngineViewer::slotOpenLinkInBrowser);
+                popup.addAction(act);
+            }
             popup.addSeparator();
             popup.addAction(mActionCollection->action(QStringLiteral("savelinkas")));
             popup.addAction(mActionCollection->action(QStringLiteral("copylinkaddress")));
